import React, { useState } from "react";
import { User, Lock, Mail } from "lucide-react";
import { useTranslation } from "react-i18next";
import { useAuth } from "../store/AuthContext";
import "./AuthPage.css";
import { useNavigate, useSearchParams } from "react-router-dom";

const AuthPage = () => {
  const { t } = useTranslation();
  const { login, register } = useAuth();
  const navigate = useNavigate();
  const [searchParams] = useSearchParams();
  const redirectUrl = searchParams.get("redirect") || "/";
  const mode = searchParams.get("mode") || "login";
  
  const [isLogin, setIsLogin] = useState(mode === "login");
  const [formData, setFormData] = useState({
    email: "",
    password: "",
    confirmPassword: "",
    name: ""
  });
  const [error, setError] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setError(null);
    try {
      if (isLogin) {
        await login(formData.email, formData.password);
        navigate(redirectUrl);
      } else {
        if (formData.password !== formData.confirmPassword) {
          setError(t("authPage.errors.passwordMismatch"));
          return;
        }
        await register(formData.name, formData.email, formData.password);
        navigate(redirectUrl);
      }
    } catch (e) {
      setError(t("authPage.errors.authFailed"));
    }
  };

  return (
    <div className="container auth">
      <div className="auth__container">
        <h2 className="auth__title">
          {isLogin ? t("authPage.title.login") : t("authPage.title.register")}
        </h2>

        {error && <p className="auth__error">{error}</p>}

        <form className="auth__form" onSubmit={handleSubmit}>
          {!isLogin && (
            <div className="auth__form-group">
              <label className="auth__label">
                <div className="auth__label-content">
                  <User size={20} />
                  {t("authPage.labels.name")}
                </div>
              </label>
              <input
                type="text"
                className="auth__input"
                value={formData.name}
                onChange={(e) =>
                  setFormData({ ...formData, name: e.target.value })
                }
                required
              />
            </div>
          )}

          <div className="auth__form-group">
            <label className="auth__label">
              <div className="auth__label-content">
                <Mail size={20} />
                {t("authPage.labels.email")}
              </div>
            </label>
            <input
              type="email"
              className="auth__input"
              value={formData.email}
              onChange={(e) =>
                setFormData({ ...formData, email: e.target.value })
              }
              required
            />
          </div>

          <div className="auth__form-group">
            <label className="auth__label">
              <div className="auth__label-content">
                <Lock size={20} />
                {t("authPage.labels.password")}
              </div>
            </label>
            <input
              type="password"
              className="auth__input"
              value={formData.password}
              onChange={(e) =>
                setFormData({ ...formData, password: e.target.value })
              }
              required
            />
          </div>

          {!isLogin && (
            <div className="auth__form-group">
              <label className="auth__label">
                <div className="auth__label-content">
                  <Lock size={20} />
                  {t("authPage.labels.confirmPassword")}
                </div>
              </label>
              <input
                type="password"
                className="auth__input"
                value={formData.confirmPassword}
                onChange={(e) =>
                  setFormData({ ...formData, confirmPassword: e.target.value })
                }
                required
              />
            </div>
          )}

          <button type="submit" className="button button-primary auth__button">
            {isLogin
              ? t("authPage.buttons.login")
              : t("authPage.buttons.register")}
          </button>
        </form>

        <p className="auth__switch">
          {isLogin
            ? t("authPage.switch.noAccount")
            : t("authPage.switch.hasAccount")}
          <button
            onClick={() => setIsLogin(!isLogin)}
            className="auth__switch-button"
          >
            {isLogin
              ? t("authPage.switch.register")
              : t("authPage.switch.login")}
          </button>
        </p>
      </div>
    </div>
  );
};

export default AuthPage;
